# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog][clog], and this project adheres to [Calendar Versioning][calver].

## [Unreleased]

## [2021.10.22]
### Added
- Added python310 support
- Added VED

### Changed
- Changed versioning scheme to calendar versioning

## [1.1.0] - 2020-08-31
### Added
- Add support for python 3.6

## [1.0.1] - 2019-11-21
### Fixed
- Fixed some typos

## [1.0.0] - 2019-11-14
### Added
- Added currency ISO codes (ISO-4217)
- Added country ISO codes (ISO-3166)


[unreleased]: https://github.com/spapanik/teritorio/compare/v2021.10.22...master
[2021.10.22]: https://github.com/spapanik/teritorio/compare/v1.1.0...v2021.10.22
[1.0.1]: https://github.com/spapanik/teritorio/compare/v1.0.1...v1.1.0
[1.0.1]: https://github.com/spapanik/teritorio/compare/v1.0.0...v1.0.1
[1.0.0]: https://github.com/spapanik/teritorio/releases/tag/v1.0.0

[clog]: https://keepachangelog.com/en/1.0.0/
[calver]: https://calver.org
